# Generated by Django 2.0.10 on 2019-02-13 11:23

import django.db.models.deletion
import modelcluster.fields
import wagtail.core.fields
import wagtail_footnotes.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("wagtailcore", "0041_group_collection_permissions_verbose_name_plural")
    ]

    operations = [
        migrations.CreateModel(
            name="Footnote",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "uuid",
                    wagtail_footnotes.fields.CustomUUIDField(
                        help_text="The ID of the footnote is shown in the rich text editor for reference.",
                        unique=True,
                        verbose_name="ID",
                    ),
                ),
                ("text", wagtail.core.fields.RichTextField()),
                (
                    "page",
                    modelcluster.fields.ParentalKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="footnotes",
                        to="wagtailcore.Page",
                    ),
                ),
            ],
        )
    ]
